==> openvas-client_1.0.4.orig.tar.gz: openvas-client-1.0.4/nessus/report.h <==
/* NessusClient -- the Nessus Client
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison
 * gives permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */
 
#ifndef _NESSUSC_REPORT_H
#define _NESSUSC_REPORT_H

#define HOLE_PRESENT 3
#define WARNING_PRESENT 2
#define NOTE_PRESENT 1

#include "context.h"

char *report_get_filename(struct context *);
int is_there_any_hole(struct arglist *);

#ifdef USE_GTK
void report_save(struct context *, int, const char *);
void open_report_selectfile(void);
#endif

#endif

==> openvas-client_2.0.3.orig.tar.gz: openvas-client-2.0.3/nessus/report.h <==
/* NessusClient -- the Nessus Client
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison
 * gives permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */
 
#ifndef _NESSUSC_REPORT_H
#define _NESSUSC_REPORT_H

#define HOLE_PRESENT 3
#define WARNING_PRESENT 2
#define NOTE_PRESENT 1
#define FALSE_PRESENT 4

#define SAVE_DETAIL_ALL 0
#define SAVE_DETAIL_HIGHMED 1
#define SAVE_DETAIL_HIGHONLY 2

#include "context.h"

gchar* report_get_filename (struct context *);
gchar* report_get_certificates_filename (struct context*);
int is_there_any_hole(struct arglist *);

#ifdef USE_GTK
void report_save(struct context *, int, const char *);
void open_report_selectfile(void);
#endif

#endif
